**Example 1: 添加忽略规则**

添加忽略规则

Input: 

```
tccli cwp ModifyBaselineRuleIgnore --cli-unfold-argument  \
    --AssetType 0 \
    --ItemIds 11 \
    --RuleName test
```

Output: 
```
{
    "Response": {
        "RequestId": "5cbf3ee7-0e7c-4190-aae8-95254726c7f2"
    }
}
```

